AZError class

Constructors

AZError({String? message, String? field, String? help, String? errorId, String? parameter})
const
AZError.fromJson(Map<String, dynamic> json)

Properties

errorId → String?
final
field → String?
final
hashCode → int
The hash code for this object.
no setterinherited
help → String?
final
message → String?
final
parameter → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited